#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AppZoo.
# @File         : __init__.py
# @Time         : 2022/8/19 下午4:25
# @Author       : yuanjie
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from appzoo.grpc_app.service import Service
from appzoo.grpc_app.client import Client
